bytes_data = b'\xe8\xb0\x83\xe7\x94\xa8\xe5\x8f\x82\xe6\x95\xb0\xe6\x9c\x89\xe8\xaf\xaf\xef\xbc\x8c\xe8\xaf\xb7\xe6\xa3\x80\xe6\x9f\xa5\xe6\x96\x87\xe6\xa1\xa3\xe3\x80\x82'
decoded_text = bytes_data.decode('utf-8')
print(decoded_text)  # 输出: "调"